@@ -69,7 +69,8 @@ static void     audio_tags_page_file_changed        (ThunarxFileInfo    *file,
 static void     audio_tags_page_taglib_file_changed (TagLib_File        *taglib_file,
                                                      AudioTagsPage      *page);
 static gboolean audio_tags_page_activate            (AudioTagsPage      *page);
-static gboolean audio_tags_page_info_activate       (GtkAction          *action,
+static gboolean audio_tags_page_info_activate       (GSimpleAction      *action,
+                                                     GVariant           *parameter,
                                                      AudioTagsPage      *page);
 static gboolean audio_tags_page_load_tags           (gpointer            data);
 
@@ -87,7 +88,7 @@ struct _AudioTagsPage
   ThunarxPropertyPage __parent__;
 
   /* Widgets */
-  GtkWidget       *table;
+  GtkWidget       *grid;
   GtkWidget       *save_button;
   GtkWidget       *info_button;
 
@@ -106,7 +107,7 @@ struct _AudioTagsPage
   guint            year;
 
   /* <private> */
-  GtkActionGroup  *action_group;
+  GActionGroup    *action_group;
 
   /* garbage collector of files */
   GSList           *files_gc;
@@ -268,16 +269,15 @@ audio_tags_page_class_init (AudioTagsPageClass *klass)
 static void
 audio_tags_page_init (AudioTagsPage *page)
 {
-  GtkObject *adjustment;
-  GtkWidget *vbox;
-  GtkWidget *alignment;
-  GtkWidget *label;
-  GtkWidget *entry;
-  GtkWidget *combo;
-  GtkWidget *spin;
-  GtkWidget *toplevel;
-  GtkAction *action;
-  guint      i;
+  GtkAdjustment *adjustment;
+  GtkWidget     *vbox;
+  GtkWidget     *label;
+  GtkWidget     *entry;
+  GtkWidget     *combo;
+  GtkWidget     *spin;
+  GtkWidget     *toplevel;
+  GSimpleAction *action;
+  guint          i;
 
   /* Default genre list */
   static const gchar *genres[] = {
@@ -310,155 +310,152 @@ audio_tags_page_init (AudioTagsPage *page)
   gtk_container_set_border_width (GTK_CONTAINER (page), 8);
 
   /* Main container */
-  vbox = gtk_vbox_new (FALSE, 8);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
   gtk_container_add (GTK_CONTAINER (page), vbox);
   gtk_widget_show (vbox);
 
-  /* Tag editor layout table */
-  page->table = gtk_table_new (7, 4, FALSE);
-  gtk_table_set_row_spacings (GTK_TABLE (page->table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (page->table), 12);
-  gtk_container_add (GTK_CONTAINER (vbox), page->table);
-  gtk_container_set_border_width (GTK_CONTAINER (page->table), 12);
-  gtk_widget_show (page->table);
+  /* Tag editor layout grid */
+  page->grid = gtk_grid_new ();
+  gtk_grid_set_row_spacing (GTK_GRID (page->grid), 6);
+  gtk_grid_set_column_spacing (GTK_GRID (page->grid), 12);
+  gtk_container_add (GTK_CONTAINER (vbox), page->grid);
+  gtk_container_set_border_width (GTK_CONTAINER (page->grid), 12);
+  gtk_widget_show (page->grid);
 
   /* Track label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Track:</b>"));
-  gtk_table_attach (GTK_TABLE (page->table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), label, 0, 0, 1, 1);
   gtk_widget_show (label);
 
-  /* Track spin button alignment */
-  alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
-  gtk_table_attach (GTK_TABLE (page->table), alignment, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
-  gtk_widget_show (alignment);
-
   /* Track adjustment */
   adjustment = gtk_adjustment_new (0, 0, 999, 1, 5, 0);
 
   /* Track spin button */
-  spin = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 0.0, 0);
+  spin = gtk_spin_button_new (adjustment, 0.0, 0);
   exo_mutual_binding_new (G_OBJECT (adjustment), "value", G_OBJECT (page), "track");
-  gtk_widget_set_tooltip_text (GTK_WIDGET (spin), _("Enter the track number here."));
-  gtk_container_add (GTK_CONTAINER (alignment), spin);
+  gtk_widget_set_tooltip_text (spin, _("Enter the track number here."));
+  gtk_widget_set_halign (spin, GTK_ALIGN_START);
+  gtk_grid_attach (GTK_GRID (page->grid), spin, 1, 0, 1, 1);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin);
   gtk_widget_show (spin);
 
   /* Year label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Year:</b>"));
-  gtk_table_attach (GTK_TABLE (page->table), label, 2, 3, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), label, 2, 0, 1, 1);
   gtk_widget_show (label);
 
-  /* Year spin button alignment */
-  alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
-  gtk_table_attach (GTK_TABLE (page->table), alignment, 3, 4, 0, 1, GTK_FILL, 0, 0, 0);
-  gtk_widget_show (alignment);
-
   /* Year spin button range description */
   adjustment = gtk_adjustment_new (2006, 1700, 9999, 1, 10, 0);
 
   /* Year spin button */
-  spin = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
+  spin = gtk_spin_button_new (adjustment, 1, 0);
   exo_mutual_binding_new (G_OBJECT (adjustment), "value", G_OBJECT (page), "year");
-  gtk_widget_set_tooltip_text (GTK_WIDGET (spin), _("Enter the release year here."));
-  gtk_container_add (GTK_CONTAINER (alignment), spin);
+  gtk_widget_set_tooltip_text (spin, _("Enter the release year here."));
+  gtk_widget_set_halign (spin, GTK_ALIGN_START);
+  gtk_grid_attach (GTK_GRID (page->grid), spin, 3, 0, 1, 1);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin);
   gtk_widget_show (spin);
 
   /* Artist label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Artist:</b>"));
-  gtk_table_attach (GTK_TABLE (page->table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), label, 0, 1, 1, 1);
   gtk_widget_show (label);
 
   /* Artist entry */
   entry = gtk_entry_new ();
   exo_mutual_binding_new (G_OBJECT (entry), "text", G_OBJECT (page), "artist");
   gtk_widget_set_tooltip_text (GTK_WIDGET (entry), _("Enter the name of the artist or author of this file here."));
-  gtk_table_attach (GTK_TABLE (page->table), entry, 1, 4, 1, 2, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+  gtk_widget_set_hexpand (entry, TRUE);
+  gtk_grid_attach (GTK_GRID (page->grid), entry, 1, 1, 3, 1);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
   gtk_widget_show (entry);
 
   /* Title label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Title:</b>"));
-  gtk_table_attach (GTK_TABLE (page->table), label, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), label, 0, 2, 1, 1);
   gtk_widget_show (label);
 
   /* Title entry */
   entry = gtk_entry_new ();
   exo_mutual_binding_new (G_OBJECT (entry), "text", G_OBJECT (page), "title");
   gtk_widget_set_tooltip_text (GTK_WIDGET (entry), _("Enter the song title here."));
-  gtk_table_attach (GTK_TABLE (page->table), entry, 1, 4, 2, 3, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+  gtk_widget_set_hexpand (entry, TRUE);
+  gtk_grid_attach (GTK_GRID (page->grid), entry, 1, 2, 3, 1);
   gtk_widget_show (entry);
 
   /* Album label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Album:</b>"));
-  gtk_table_attach (GTK_TABLE (page->table), label, 0, 1, 3, 4, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), label, 0, 3, 1, 1);
   gtk_widget_show (label);
 
   /* Album entry */
   entry = gtk_entry_new ();
   exo_mutual_binding_new (G_OBJECT (entry), "text", G_OBJECT (page), "album");
   gtk_widget_set_tooltip_text (GTK_WIDGET (entry), _("Enter the album/record title here."));
-  gtk_table_attach (GTK_TABLE (page->table), entry, 1, 4, 3, 4, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+  gtk_widget_set_hexpand (entry, TRUE);
+  gtk_grid_attach (GTK_GRID (page->grid), entry, 1, 3, 3, 1);
   gtk_widget_show (entry);
 
   /* Comment label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Comment:</b>"));
-  gtk_table_attach (GTK_TABLE (page->table), label, 0, 1, 4, 5, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), label, 0, 4, 1, 1);
   gtk_widget_show (label);
 
   /* Comment entry */
   entry = gtk_entry_new ();
   exo_mutual_binding_new (G_OBJECT (entry), "text", G_OBJECT (page), "comment");
   gtk_widget_set_tooltip_text (GTK_WIDGET (entry), _("Enter your comments here."));
-  gtk_table_attach (GTK_TABLE (page->table), entry, 1, 4, 4, 5, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+  gtk_widget_set_hexpand (entry, TRUE);
+  gtk_grid_attach (GTK_GRID (page->grid), entry, 1, 4, 3, 1);
   gtk_widget_show (entry);
 
   /* Genre label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Genre:</b>"));
-  gtk_table_attach (GTK_TABLE (page->table), label, 0, 1, 5, 6, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), label, 0, 5, 1, 1);
   gtk_widget_show (label);
 
   /* Genre combo box */
-  combo = gtk_combo_box_entry_new_text ();
-  exo_mutual_binding_new (G_OBJECT (GTK_BIN (combo)->child), "text", G_OBJECT (page), "genre");
+  combo = gtk_combo_box_text_new_with_entry ();
+  exo_mutual_binding_new (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo))), "text", G_OBJECT (page), "genre");
   gtk_widget_set_tooltip_text (GTK_WIDGET (combo), _("Select or enter the genre of this song here."));
-  gtk_table_attach (GTK_TABLE (page->table), combo, 1, 4, 5, 6, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (page->grid), combo, 1, 5, 3, 1);
   gtk_widget_show (combo);
 
   for (i=0; i<G_N_ELEMENTS (genres); i++)
-    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), genres[i]);
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), genres[i]);
 
   /* Create action group for the page */
-  page->action_group = gtk_action_group_new ("audio-tags-page-actions");
+  page->action_group = G_ACTION_GROUP (g_simple_action_group_new ());
+  gtk_widget_insert_action_group (GTK_WIDGET (page), "audio-tags-page-actions", page->action_group);
 
   /* Create and add the save action */
-  action = gtk_action_new ("save", _("_Save"), _("Save audio tags."), GTK_STOCK_SAVE);
-  gtk_action_group_add_action (page->action_group, action);
+  action = g_simple_action_new ("save", NULL);
+  g_action_map_add_action (G_ACTION_MAP (page->action_group), G_ACTION (action));
 
   /* Connect to save action */
   g_signal_connect_swapped (G_OBJECT (action), "activate", G_CALLBACK (audio_tags_page_activate), page);
 
   /* Create and add the info action */
-  action = gtk_action_new ("info", _("_Information"), _("Display more detailed information about this audio file."), GTK_STOCK_PROPERTIES);
-  gtk_action_group_add_action (page->action_group, action);
+  action = g_simple_action_new ("info", NULL);
+  g_action_map_add_action (G_ACTION_MAP (page->action_group), G_ACTION (action));
 
   /* Determine parent window and assign it to the action */
   toplevel = gtk_widget_get_toplevel (GTK_WIDGET (page));
-  if (GTK_WIDGET_TOPLEVEL (toplevel))
+  if (gtk_widget_is_toplevel (toplevel))
     g_object_set_data_full (G_OBJECT (action), "window", g_object_ref (G_OBJECT (toplevel)), (GDestroyNotify)g_object_unref);
 
   /* Connect to the info action */
@@ -548,7 +545,6 @@ audio_tags_page_dialog_new (GtkWindow *window,
   GtkWidget     *dialog;
   GtkWidget     *button;
   AudioTagsPage *page;
-  GtkAction     *action;
 
   /* Create the audio tags page */
   page = audio_tags_page_new ();
@@ -560,26 +556,22 @@ audio_tags_page_dialog_new (GtkWindow *window,
   dialog = gtk_dialog_new_with_buttons (_("Edit Tags"),
                                         window,
                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        GTK_STOCK_CANCEL,
+                                        _("_Cancel"),
                                         GTK_RESPONSE_CANCEL,
                                         NULL);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
   /* Add page to the dialog */
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), GTK_WIDGET (page));
+  gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), GTK_WIDGET (page));
   gtk_widget_show (GTK_WIDGET (page));
 
   /* Create save button */
-  button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
+  button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Save"), GTK_RESPONSE_OK);
 
   /* Connect save button to the "save" action */
-  action = gtk_action_group_get_action (page->action_group, "save");
-  gtk_action_connect_proxy (action, button);
-
-  /* Add save button to the dialog */
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (button), "audio-tags-page-actions.save");
+  gtk_widget_insert_action_group (GTK_WIDGET (dialog), "audio-tags-page-actions", page->action_group);
 
   return dialog;
 }
@@ -949,14 +941,15 @@ audio_tags_page_activate (AudioTagsPage *page)
 
 
 static gboolean
-audio_tags_page_info_activate (GtkAction *action,
-                               AudioTagsPage *page)
+audio_tags_page_info_activate (GSimpleAction      *action,
+                               GVariant           *parameter,
+                               AudioTagsPage      *page)
 {
   const TagLib_AudioProperties *properties;
 
   GtkWindow *window;
   GtkWidget *dialog;
-  GtkWidget *table;
+  GtkWidget *grid;
   GtkWidget *label;
 
   /* Audio information */
@@ -982,15 +975,13 @@ audio_tags_page_info_activate (GtkAction *action,
   dialog = gtk_dialog_new_with_buttons (_("Audio Information"),
                                         window,
                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        GTK_STOCK_CLOSE,
+                                        _("_Close"),
                                         GTK_RESPONSE_CLOSE,
                                         NULL);
 
-  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-
   /* Retrieve audio information */
   properties = taglib_file_audioproperties (page->taglib_file);
-  length = g_strdup_printf (_("%d:%d Minutes"), taglib_audioproperties_length (properties) / 60, taglib_audioproperties_length (properties) % 60);
+  length = g_strdup_printf (_("%d:%02d Minutes"), taglib_audioproperties_length (properties) / 60, taglib_audioproperties_length (properties) % 60);
   bitrate = g_strdup_printf (_("%d KBit/s"), taglib_audioproperties_bitrate (properties));
   samplerate = g_strdup_printf (_("%d Hz"), taglib_audioproperties_samplerate (properties));
   channels = g_strdup_printf ("%d", taglib_audioproperties_channels (properties));
@@ -1005,103 +996,103 @@ audio_tags_page_info_activate (GtkAction *action,
   filesize = g_format_size_for_display (g_file_info_get_size (fileinfo));
 #endif
 
-  /* Create layout table */
-  table = gtk_table_new (7, 2, FALSE);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), table);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 12);
-  gtk_widget_show (table);
+  /* Create layout grid */
+  grid = gtk_grid_new ();
+  gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
+  gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), grid);
+  gtk_container_set_border_width (GTK_CONTAINER (grid), 12);
+  gtk_widget_show (grid);
 
   /* Filename label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Filename:</b>"));
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
   gtk_widget_show (label);
 
   /* Filename display */
   label = gtk_label_new (filename);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 1, 0, 1, 1);
   gtk_widget_show (label);
 
   /* Filesize label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Filesize:</b>"));
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
   gtk_widget_show (label);
 
   /* Filesize display */
   label = gtk_label_new (filesize);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 1, 1, 1, 1);
   gtk_widget_show (label);
 
   /* Mimetype label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>MIME Type:</b>"));
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 2, 1, 1);
   gtk_widget_show (label);
 
   /* Mimetype display */
   label = gtk_label_new (mimetype);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 2, 3, GTK_FILL, 0, 0, 0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 1, 2, 1, 1);
   gtk_widget_show (label);
 
   /* Bitrate label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Bitrate:</b>"));
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 3, 1, 1);
   gtk_widget_show (label);
 
   /* Bitrate display */
   label = gtk_label_new (bitrate);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 3, 4, GTK_FILL, 0, 0, 0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 1, 3, 1, 1);
   gtk_widget_show (label);
 
   /* Samplerate label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Samplerate:</b>"));
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 4, 1, 1);
   gtk_widget_show (label);
 
   /* Samplerate display */
   label = gtk_label_new (samplerate);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 4, 5, GTK_FILL, 0, 0, 0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 1, 4, 1, 1);
   gtk_widget_show (label);
 
   /* Channels label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Channels:</b>"));
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 5, 1, 1);
   gtk_widget_show (label);
 
   /* Channels display */
   label = gtk_label_new (channels);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 5, 6, GTK_FILL, 0, 0, 0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 1, 5, 1, 1);
   gtk_widget_show (label);
 
   /* Length label */
   label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0f);
   gtk_label_set_markup (GTK_LABEL (label), _("<b>Length:</b>"));
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 6, 7, GTK_FILL, 0, 0, 0);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 6, 1, 1);
   gtk_widget_show (label);
 
   /* Length display */
   label = gtk_label_new (length);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-  gtk_table_attach (GTK_TABLE (table), label, 1, 2, 6, 7, GTK_FILL, 0, 0, 0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_grid_attach (GTK_GRID (grid), label, 1, 6, 1, 1);
   gtk_widget_show (label);
 
   /* Run dialog */
@@ -1184,11 +1175,8 @@ void
 audio_tags_page_set_show_save_button (AudioTagsPage   *page,
                                       gboolean         show)
 {
-  GtkAction *action;
-
   g_return_if_fail (IS_AUDIO_TAGS_PAGE (page));
-  g_return_if_fail (page->table != NULL || GTK_IS_TABLE (page->table));
-  g_return_if_fail (page->action_group != NULL || GTK_IS_ACTION_GROUP (page->action_group));
+  g_return_if_fail (page->grid != NULL || GTK_IS_GRID (page->grid));
 
   if (G_LIKELY (show))
     {
@@ -1197,22 +1185,22 @@ audio_tags_page_set_show_save_button (AudioTagsPage   *page,
         return;
 
       /* Info button */
-      page->info_button = gtk_button_new_from_stock (GTK_STOCK_PROPERTIES);
-      gtk_table_attach (GTK_TABLE (page->table), page->info_button, 2, 3, 6, 7, GTK_FILL, 0, 0, 0);
+      page->info_button = gtk_button_new_with_mnemonic (_("_Information"));
+      gtk_widget_set_tooltip_text (page->info_button, _("Display more detailed information about this audio file."));
+      gtk_grid_attach (GTK_GRID (page->grid), page->info_button, 2, 6, 1, 1);
       gtk_widget_show (page->info_button);
 
       /* Connect to info action */
-      action = gtk_action_group_get_action (page->action_group, "info");
-      gtk_action_connect_proxy (action, page->info_button);
+      gtk_actionable_set_action_name (GTK_ACTIONABLE (page->info_button), "audio-tags-page-actions.info");
 
       /* Save button */
-      page->save_button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
-      gtk_table_attach (GTK_TABLE (page->table), page->save_button, 3, 4, 6, 7, GTK_FILL, 0, 0, 0);
+      page->save_button = gtk_button_new_with_mnemonic (_("_Save"));
+      gtk_widget_set_tooltip_text (page->save_button, _("Save audio tags."));
+      gtk_grid_attach (GTK_GRID (page->grid), page->save_button, 3, 6, 1, 1);
       gtk_widget_show (page->save_button);
 
       /* Connect to save action */
-      action = gtk_action_group_get_action (page->action_group, "save");
-      gtk_action_connect_proxy (action, page->save_button);
+      gtk_actionable_set_action_name (GTK_ACTIONABLE (page->save_button), "audio-tags-page-actions.save");
     }
   else
     {
